Module writer

Structs

FixedLengthFileWriter
The writer struct for fixed-length files (.flf).
FixedLengthFileWriterBuilder
A helper struct for building an instance of a FixedLengthFileWriter struct.
FixedLengthFileWriterProperties
A collection of various file properties for the FixedLengthFileWriter.
FixedLengthFileWriterPropertiesBuilder
A helper struct for building an instance of a FixedLengthFileWriterProperties struct.

Traits

Writer
A trait providing functions to write buffered data to some target.

Type Aliases

WriterRef
A short-hand notation for a generic writer implementation.