Structs
- Fixed
Length File Writer - The writer struct for fixed-length files (.flf).
- Fixed
Length File Writer Builder - A helper struct for building an instance of a
FixedLengthFileWriterstruct. - Fixed
Length File Writer Properties - A collection of various file properties for the
FixedLengthFileWriter. - Fixed
Length File Writer Properties Builder - A helper struct for building an instance of a
FixedLengthFileWriterPropertiesstruct.
Traits
- Writer
- A trait providing functions to write buffered data to some target.
Type Aliases
- Writer
Ref - A short-hand notation for a generic writer implementation.