Structs
- The writer struct for fixed-length files (.flf).
- A helper struct for building an instance of a
FixedLengthFileWriterstruct. - A collection of various file properties for the
FixedLengthFileWriter. - A helper struct for building an instance of a
FixedLengthFileWriterPropertiesstruct.
Traits
- A trait providing functions to write buffered data to some target.
Type Aliases
- A short-hand notation for a generic writer implementation.